@@ -1,5 +1,7 @@
+from django.conf import settings
 from rest_framework.views import APIView
 from rest_framework.response import Response
+
 from ..app_settings import conf
 from ..client import TwoFAClient
 from .. import errors
@@ -10,9 +12,10 @@ class BaseView(APIView):
     serializer_class = None
 
     def _get_response(self, data, status_code=200):
-        data["_debug"] = {
-            "session": self.twofa_client.session._to_dict()
-        }
+        if settings.DEBUG:
+            data["_debug"] = {
+                "session": self.twofa_client.session._to_dict()
+            }
 
         return Response(
             data,
@@ -116,7 +119,8 @@ class SendView(BaseView):
         )
 
         return self.get_serialized_response(
-            verification_id=verification_sid
+            verification_id=verification_sid,
+            display=self.twofa_client.get_send_message(method)
         )
 
 
@@ -127,24 +131,27 @@ class VerifyView(BaseView):
         verification_id = self.request.data.get("verification_id")
         code = self.request.data.get("code")
 
-        # FIXME - once a user has reached the max attempts, we should stop them here, and not do any further validations
-
         if not code:
             raise errors.MalformedRequest(
                 missing_field="code"
             )
 
-        if len(str(code)) != conf.token_length() or not str(code).isnumeric():
-            # TODO - make sure this matches what would return if the user sent an invalid token of the correct length
-            raise errors.InvalidVerificationCode()
+        # Max attempts, code validation, and expiration checks happen in check_verification
+        # to maintain consistency
 
         verified = self.twofa_client.check_verification(
             verification_sid=verification_id,
             code=code
         )
 
+        if verified:
+            display = self.twofa_client.get_message("verified")
+        else:
+            display = self.twofa_client.get_message("incorrect_code")
+
         return self.get_serialized_response(
-            verified=verified
+            verified=verified,
+            display=display
         )
 
 
@@ -176,4 +183,4 @@ class MethodsView(BaseView):
             return Response({"verification_methods": methods})
 
         except Exception:
-            return Response({"verification_methods": []}, status=400)
\ No newline at end of file
+            return Response({"verification_methods": []}, status=400)
