@@ -1,6 +1,7 @@
 from django import forms
+from django.core.exceptions import ValidationError
 import pycountry
-from .client import TwoFAClient
+
 from .app_settings import conf
 
 
@@ -38,3 +39,11 @@ class Twilio2FAVerifyForm(forms.Form):
     token = forms.CharField(
         required=True
     )
+
+    def clean_token(self):
+        token = self.cleaned_data["token"]
+
+        if len(str(token)) != conf.token_length() or not str(token).isnumeric():
+            raise ValidationError(f"Please provide a valid {conf.token_length()} digit token")
+
+        return token
